==> haskell-gtk-sni-tray-0.1.8.1-213-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gtk-sni-tray.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 gtk-sni-tray
version:              0.1.8.1
visibility:           public
id:                   gtk-sni-tray-0.1.8.1-KbFxujBoObRBjTHx85hNgs
key:                  gtk-sni-tray-0.1.8.1-KbFxujBoObRBjTHx85hNgs
license:              BSD-3-Clause
copyright:            2018 Ivan Malison
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:             https://github.com/IvanMalison/gtk-sni-tray#readme
synopsis:             A standalone StatusNotifierItem/AppIndicator tray
description:
    Please see the README on Github at <https://github.com/IvanMalison/gtk-sni-tray#readme>

category:             System
abi:                  014ed0eccefbc1b7aba0a190f637fb06
exposed:              True
exposed-modules:      StatusNotifier.TransparentWindow StatusNotifier.Tray
hidden-modules:       Paths_gtk_sni_tray
import-dirs:          /usr/lib/ghc-9.2.8/site-local/gtk-sni-tray-0.1.8.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/gtk-sni-tray-0.1.8.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gtk-sni-tray
hs-libraries:         HSgtk-sni-tray-0.1.8.1-KbFxujBoObRBjTHx85hNgs
extra-libraries:
    gtk-3 gdk-3 z pangocairo-1.0 cairo-gobject gdk_pixbuf-2.0 atk-1.0
    pango-1.0 cairo harfbuzz gio-2.0 gobject-2.0 glib-2.0

include-dirs:
    /usr/include/gtk-3.0 /usr/include/pango-1.0
    /usr/include/cloudproviders /usr/include/cairo
    /usr/include/gdk-pixbuf-2.0 /usr/include/at-spi2-atk/2.0
    /usr/include/at-spi-2.0 /usr/include/atk-1.0 /usr/include/dbus-1.0
    /usr/lib/dbus-1.0/include /usr/include/fribidi
    /usr/include/pixman-1 /usr/include/harfbuzz /usr/include/freetype2
    /usr/include/libpng16 /usr/include/gio-unix-2.0
    /usr/include/glib-2.0 /usr/lib/glib-2.0/include
    /usr/include/libmount /usr/include/blkid /usr/include/sysprof-6

depends:
    base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    dbus-1.3.1-5Omqas1LOie9CiKavSEZ2h directory-1.3.6.2
    enclosed-exceptions-1.0.3-Jvx01ErNeXdKu9ex9t3MCA filepath-1.4.2.2
    gi-cairo-1.0.29-98ukf0l3KypK3HHEJgAOR2
    gi-cairo-connector-0.1.1-2VrldNrg9emGGP04acUDGi
    gi-cairo-render-0.1.2-9D8K2zcb3kx1lMgi4sCYPv
    gi-dbusmenugtk3-0.4.14-BGjXe6wBjuqJaJZsLo5vFv
    gi-gdk-3.0.26-6LEoVAPBt3k7n0Ysq7qm4k
    gi-gdkpixbuf-2.0.31-By1Wdf4hr283gKiz9CJVQy
    gi-glib-2.0.29-AT4Cos2rGYV5C8IxtqDccn
    gi-gtk-3.0.38-9hGTR95PD1p2zybfKxWITM
    gtk-strut-0.1.3.2-FKpqfplFuS85BVMajMuYX
    haskell-gi-0.26.9-GLAWaabTce0ISHCvFFXgq3
    haskell-gi-base-0.26.6-2Iq9Kyqd3Sc9DWwShfcztO
    hslogger-1.3.1.1-AOdgOg5sBRh2ItTug2ZoVG
    status-notifier-item-0.3.1.0-g7qUso3qNI9euhvVWLVBl text-1.2.5.0
    transformers-0.5.6.2 transformers-base-0.4.6-ABNpRFPMzKw54ilqxg2n9F
    unix-2.7.2.2

haddock-interfaces:
    /usr/share/doc/haskell-gtk-sni-tray/html/gtk-sni-tray.haddock

haddock-html:         /usr/share/doc/haskell-gtk-sni-tray/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-gtk-sni-tray-0.1.8.1-218-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gtk-sni-tray.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 gtk-sni-tray
version:              0.1.8.1
visibility:           public
id:                   gtk-sni-tray-0.1.8.1-AaUrYUaOJRS6aXf12vqs3J
key:                  gtk-sni-tray-0.1.8.1-AaUrYUaOJRS6aXf12vqs3J
license:              BSD-3-Clause
copyright:            2018 Ivan Malison
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:             https://github.com/IvanMalison/gtk-sni-tray#readme
synopsis:             A standalone StatusNotifierItem/AppIndicator tray
description:
    Please see the README on Github at <https://github.com/IvanMalison/gtk-sni-tray#readme>

category:             System
abi:                  0e7e12c37695a7f0b7e9c1fb2fa0799c
exposed:              True
exposed-modules:      StatusNotifier.TransparentWindow StatusNotifier.Tray
hidden-modules:       Paths_gtk_sni_tray
import-dirs:          /usr/lib/ghc-9.2.8/site-local/gtk-sni-tray-0.1.8.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/gtk-sni-tray-0.1.8.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gtk-sni-tray
hs-libraries:         HSgtk-sni-tray-0.1.8.1-AaUrYUaOJRS6aXf12vqs3J
extra-libraries:
    gtk-3 gdk-3 z pangocairo-1.0 cairo-gobject gdk_pixbuf-2.0 atk-1.0
    pango-1.0 cairo harfbuzz gio-2.0 gobject-2.0 glib-2.0

include-dirs:
    /usr/include/gtk-3.0 /usr/include/pango-1.0
    /usr/include/cloudproviders /usr/include/cairo
    /usr/include/gdk-pixbuf-2.0 /usr/include/at-spi2-atk/2.0
    /usr/include/at-spi-2.0 /usr/include/atk-1.0 /usr/include/dbus-1.0
    /usr/lib/dbus-1.0/include /usr/include/fribidi
    /usr/include/pixman-1 /usr/include/harfbuzz /usr/include/freetype2
    /usr/include/libpng16 /usr/include/gio-unix-2.0
    /usr/include/glib-2.0 /usr/lib/glib-2.0/include
    /usr/include/libmount /usr/include/blkid /usr/include/sysprof-6

depends:
    base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    dbus-1.3.1-1dTxxX9MaqcK7bQEpbWGsH directory-1.3.6.2
    enclosed-exceptions-1.0.3-Jvx01ErNeXdKu9ex9t3MCA filepath-1.4.2.2
    gi-cairo-1.0.29-bnYIQFCWWv7lNoExTnBIM
    gi-cairo-connector-0.1.1-9Km6EjFYsZ9FQHwAIwCa7J
    gi-cairo-render-0.1.2-9D8K2zcb3kx1lMgi4sCYPv
    gi-dbusmenugtk3-0.4.14-JjfgVoYWZNvBX1nh7T4VIE
    gi-gdk-3.0.26-EC1P5AzRMtM5smwumM37jg
    gi-gdkpixbuf-2.0.31-DlBP4qiv9jMFqlajEAVkRV
    gi-glib-2.0.29-uu568nsYAdALd8WZ8IQEb
    gi-gtk-3.0.39-LiIYGgNiPMLHmW2adxmMMC
    gtk-strut-0.1.3.2-Iqy8j2UyAdCKEpKWzHGBNK
    haskell-gi-0.26.9-1IwfIGxaQ8BHlwsDVMqGUZ
    haskell-gi-base-0.26.6-2Iq9Kyqd3Sc9DWwShfcztO
    hslogger-1.3.1.2-GdSqzdUQbNiJnHwr0PdfmW
    status-notifier-item-0.3.1.0-FZsIwnhjzn91K9bamNVxyM text-1.2.5.0
    transformers-0.5.6.2 transformers-base-0.4.6-ABNpRFPMzKw54ilqxg2n9F
    unix-2.7.2.2

haddock-interfaces:
    /usr/share/doc/haskell-gtk-sni-tray/html/gtk-sni-tray.haddock

haddock-html:         /usr/share/doc/haskell-gtk-sni-tray/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
